ImageBuffer

Struct ImageBuffer 

pub struct ImageBuffer { /* private fields */ }
Represents an paletted image, with each pixel being an 8bits number.

Images with no pixel are valid, and it is guarantted that width*height == buffer.len()

Implementations

Source

impl ImageBuffer

pub fn new_from_vec( buffer: Vec<u8>, width: u16, height: u16, ) -> Option<ImageBuffer>

pub fn width(&self) -> u16

pub fn height(&self) -> u16

pub fn buffer(&self) -> &Vec<u8>

pub fn have_pixel(&self) -> bool

pub fn get_pixel(&self, x: u16, y: u16) -> Option<u8>

pub fn cut_top(&mut self) -> usize

pub fn cut_bottom(&mut self) -> usize

pub fn cut_right(&mut self) -> usize

pub fn cut_left(&mut self) -> usize

pub fn get_fragment( &self, start_x: u16, start_y: u16, width: u16, height: u16, default: u8, ) -> ImageBuffer