Struct pmd_wan::MetaFrame[][src]

pub struct MetaFrame {
    pub unk1: u16,
    pub unk2: u16,
    pub unk3_4: Option<(bool, bool)>,
    pub unk5: bool,
    pub image_index: usize,
    pub offset_y: i8,
    pub offset_x: i16,
    pub v_flip: bool,
    pub h_flip: bool,
    pub is_mosaic: bool,
    pub pal_idx: u16,
    pub resolution: Resolution,
}
A MetaFrame may reference an crate::ImageBytes, that will form a single (or all if small enought) part of an crate::MetaFrameGroup

Fields

unk1: u16unk2: u16

Seems to be related to allocation. Each MetaFrame in the group should increment it from the value of Resolution::chunk_to_allocate_for_metaframe, starting at 0 for each group This can’t be generalised to every sprites

unk3_4: Option<(bool, bool)>

Two value with unknown property in the offset y data. most of the time, the unk3 is equal to offset_y < 0, and unk4 the inverse (will be automatically computed if set to None) otherwise the two boolean in the tuple will be used

unk5: boolimage_index: usizeoffset_y: i8offset_x: i16v_flip: boolh_flip: boolis_mosaic: boolpal_idx: u16resolution: Resolution

Implementations

parse a metaframe from the file. The second value is whether the “is_last” bit has been set to true, meaning it’s the last MetaFrame from the MetaFrameGroup